@@ -18,6 +18,36 @@ class Alchemy (unittest.IsolatedAsyncioTestCase):
         await self.db.createDbIfNotExists()
         
 
+    async def test_deleteSelect(self):
+        await self.db.SaQuery('''CREATE TABLE IF NOT EXISTS `saTable4` (
+            `id` serial PRIMARY KEY,
+            `val` varchar(255)
+        )''')
+
+        metadata = sa.MetaData()
+
+        tbl = sa.Table('saTable4', metadata,
+            sa.Column('id', sa.Integer, primary_key=True),
+            sa.Column('val', sa.String(255))
+        )
+        
+        res = await self.db.SaQuery([
+            tbl.insert().values([{'val':'testToDel'}, {'val':'testToDel2'}]),
+            sa.select([tbl])
+        ])
+
+        df = pd.DataFrame(res[0])
+        self.assertTrue('testToDel' in df['val'].values)
+        self.assertTrue('testToDel2' in df['val'].values)
+
+        res = await self.db.SaQuery([
+            tbl.delete().where(tbl.c['val'] == 'testToDel'),
+            sa.select([tbl])
+        ])
+        logging.debug(res)
+
+
+
     async def test_insertSelect(self):
         await self.db.SaQuery('''CREATE TABLE IF NOT EXISTS `saTable3` (
             `id` serial PRIMARY KEY,
